@@ -34,6 +34,7 @@ struct _GIrModule
   gchar *name;
   gchar *version;
   gchar *shared_library;
+  gchar *c_prefix;
   GList *dependencies;
   GList *entries;
 
@@ -50,7 +51,8 @@ struct _GIrModule
 
 GIrModule *g_ir_module_new            (const gchar *name,
 				       const gchar *nsversion,
-				       const gchar *module_filename);
+				       const gchar *module_filename,
+				       const gchar *c_prefix);
 void       g_ir_module_free           (GIrModule  *module);
 
 void       g_ir_module_add_include_module (GIrModule  *module,
