@@ -27,6 +27,7 @@
 
 G_BEGIN_DECLS
 
+typedef struct _GIrTypelibBuild GIrTypelibBuild;
 typedef struct _GIrNode GIrNode; 
 typedef struct _GIrNodeFunction GIrNodeFunction;
 typedef struct _GIrNodeParam GIrNodeParam;
@@ -45,6 +46,16 @@ typedef struct _GIrNodeErrorDomain GIrNodeErrorDomain;
 typedef struct _GIrNodeXRef GIrNodeXRef;
 typedef struct _GIrNodeUnion GIrNodeUnion;
 
+struct _GIrTypelibBuild {
+  GIrModule  *module;
+  GList       *modules;
+  GHashTable  *strings;
+  GHashTable  *types;
+  GList       *offset_ordered_nodes;
+  guint32      n_attributes;
+  guchar      *data; 
+};
+
 typedef enum 
 {
   G_IR_NODE_INVALID      =  0,
@@ -73,6 +84,10 @@ struct _GIrNode
 {
   GIrNodeTypeId type;
   gchar *name;
+
+  guint32 offset; /* Assigned as we build the typelib */
+
+  GHashTable *attributes;
 };
 
 struct _GIrNodeXRef
@@ -143,6 +158,10 @@ struct _GIrNodeParam
   gboolean allow_none;
   gboolean transfer;
   gboolean shallow_transfer;
+  GIScopeType scope;
+  
+  gint8 closure;
+  gint8 destroy;
   
   GIrNodeType *type;
 };
@@ -195,6 +214,8 @@ struct _GIrNodeVFunc
   gboolean must_not_be_implemented;
   gboolean is_class_closure;
   
+  char *invoker;
+
   GList *parameters;
   GIrNodeParam *result;      
 
@@ -224,6 +245,7 @@ struct _GIrNodeInterface
   gchar *gtype_init;
 
   gchar *parent;
+  gchar *glib_type_struct;
   
   GList *interfaces;
   GList *prerequisites;
@@ -288,6 +310,7 @@ struct _GIrNodeStruct
 
   gboolean deprecated;
   gboolean disguised;
+  gboolean is_gtype_struct;
 
   gchar *gtype_name;
   gchar *gtype_init;
@@ -334,14 +357,12 @@ GIrNode * g_ir_node_new             (GIrNodeTypeId type);
 void      g_ir_node_free            (GIrNode    *node);
 guint32   g_ir_node_get_size        (GIrNode    *node);
 guint32   g_ir_node_get_full_size   (GIrNode    *node);
-void      g_ir_node_build_typelib   (GIrNode    *node,
-				     GIrModule  *module,
-				     GList       *modules,
-				     GHashTable  *strings,
-				     GHashTable  *types,
-				     guchar      *data,
-				     guint32     *offset,
-				     guint32     *offset2);
+guint32   g_ir_node_get_attribute_size (GIrNode *node);
+void      g_ir_node_build_typelib   (GIrNode         *node,
+                                     GIrNode         *parent,
+                                     GIrTypelibBuild *build,
+                                     guint32         *offset,
+                                     guint32         *offset2);
 int       g_ir_node_cmp             (GIrNode    *node,
 				     GIrNode    *other);
 gboolean  g_ir_node_can_have_member (GIrNode    *node);
